===================
Contributed Modules
===================

Some useful code contributed by the community is shipped with Werkzeug
as part of the ``contrib`` module.

.. warning::
    The code in this module is being deprecated, to be moved or removed
    in version 1.0. Be sure to pay attention to any deprecation warnings
    and update your code appropriately.

.. toctree::
   :maxdepth: 2

   atom
   sessions
   securecookie
   cache
   wrappers
   iterio
   fixers
   profiler
   lint
